@@ -49,9 +49,7 @@ class LkeapClient(AbstractClient):
         - DeepSeek-R1-0528（model 参数值为**deepseek-r1-0528**）
             - DeepSeek-R1-0528为671B 模型，架构优化与训练策略升级后，相比上一版本在代码生成、长文本处理和复杂推理领域提升明显。
             -  支持96K上下文长度，最大输入长度64k，最大输出16k（默认4k），最大思维链输出长度32k。
-        - DeepSeek-Prover-V2（model 参数值为**deepseek-prover-v2**）
-            - DeepSeek-Prover-V2 为671B 参数 MoE 模型，在数学定理证明和复杂计算任务中表现出色。
-            -  支持64K上下文长度，最大输出16k。
+
 
 
         ### 计费说明
@@ -66,8 +64,6 @@ class LkeapClient(AbstractClient):
 
             - DeepSeek-V3-0324 模型 | 输入：0.002元/千token | 输出：0.008元/千token
 
-            - DeepSeek-Prover-V2 模型 | 暂不计费
-
 
         ### Openai兼容协议接口
         知识引擎原子能力大模型对话 API 兼容了 OpenAI 的接口规范，这意味着您可以直接使用 OpenAI 官方提供的 SDK 来调用大模型对话接口。您仅需要将 base_url 和 [api_key](https://cloud.tencent.com/document/product/1772/115970) 替换成相关配置，不需要对应用做额外修改，即可无缝将您的应用切换到相应的大模型。请参考文档：[Deepseek OpenAI对话接口](https://cloud.tencent.com/document/product/1772/115969)。
