@@ -38,6 +38,9 @@ FAILEDOPERATION_DESCRIBESERVICEERROR = 'FailedOperation.DescribeServiceError'
 # 查询service列表失败。
 FAILEDOPERATION_DESCRIBESERVICELISTERROR = 'FailedOperation.DescribeServiceListError'
 
+# 更新 ingress 失败。
+FAILEDOPERATION_UPDATEINGRESSERROR = 'FailedOperation.UpdateIngressError'
+
 # 请求响应超时。
 INTERNALERROR_ACTIONREADTIMEOUT = 'InternalError.ActionReadTimeout'
 
@@ -107,6 +110,9 @@ INTERNALERROR_DESCRIBESERVICELISTERROR = 'InternalError.DescribeServiceListError
 # 修改配置失败。
 INTERNALERROR_MODIFYCONFIGDATAERROR = 'InternalError.ModifyConfigDataError'
 
+# 修改网关的转发配置失败。
+INTERNALERROR_MODIFYGATEWAYINGRESSERROR = 'InternalError.ModifyGatewayIngressError'
+
 # 修改 LogConfig 错误。
 INTERNALERROR_MODIFYLOGCONFIGERROR = 'InternalError.ModifyLogConfigError'
 
@@ -140,6 +146,12 @@ INVALIDPARAMETER_SERVICEUSERESERVESUFFIX = 'InvalidParameter.ServiceUseReserveSu
 # PortMapping规则数量超过限制。
 INVALIDPARAMETER_TOOMANYPORTMAPPINGRULES = 'InvalidParameter.TooManyPortMappingRules'
 
+# 权限不足或缺少相关角色
+INVALIDPARAMETER_UNAUTHORIZEDORMISSINGROLE = 'InvalidParameter.UnauthorizedOrMissingRole'
+
+# 自动创建将超过 vpc 限额。
+INVALIDPARAMETER_VPCOVERQUOTA = 'InvalidParameter.VpcOverQuota'
+
 # APM 没有与当前环境绑定。
 INVALIDPARAMETERVALUE_APMNOTBIND = 'InvalidParameterValue.ApmNotBind'
 
@@ -158,6 +170,9 @@ INVALIDPARAMETERVALUE_ATLEASTONESCALERRULESHOULDBEAPPLIED = 'InvalidParameterVal
 # 只支持绑定一种弹性伸缩。
 INVALIDPARAMETERVALUE_AUTOSCALERLARGERTHANONE = 'InvalidParameterValue.AutoScalerLargerThanOne'
 
+# 弹性规则名称不合法, 长度必须小于20。
+INVALIDPARAMETERVALUE_AUTOSCALERNAMEINVALID = 'InvalidParameterValue.AutoScalerNameInvalid'
+
 # 不能覆盖其他应用的访问方式。
 INVALIDPARAMETERVALUE_CANNOTOVERWRITEOTHERAPPLICATIONSERVICE = 'InvalidParameterValue.CannotOverWriteOtherApplicationService'
 
@@ -170,6 +185,9 @@ INVALIDPARAMETERVALUE_CONFIGDATAALREADYEXIST = 'InvalidParameterValue.ConfigData
 # 配置不合法。
 INVALIDPARAMETERVALUE_CONFIGDATAINVALID = 'InvalidParameterValue.ConfigDataInvalid'
 
+# 创建环境createRegion参数错误。
+INVALIDPARAMETERVALUE_CREATENAMESPACEUNSUPPORTREGIONERROR = 'InvalidParameterValue.CreateNamespaceUnsupportRegionError'
+
 # 定时弹性伸缩目标实例数不合法。
 INVALIDPARAMETERVALUE_CRONHPAREPLICASINVALID = 'InvalidParameterValue.CronHpaReplicasInvalid'
 
@@ -194,6 +212,9 @@ INVALIDPARAMETERVALUE_HPATHRESHOLDINVALID = 'InvalidParameterValue.HpaThresholdI
 # 访问配置重定向需要启用 HTTPS。
 INVALIDPARAMETERVALUE_INGRESSREWRITEREQUIREDHTTPSENABLE = 'InvalidParameterValue.IngressRewriteRequiredHttpsEnable'
 
+# 自动重定向规则冲突，请检查是否存在同一个path的http/https转发。
+INVALIDPARAMETERVALUE_INGRESSRULESCONFLICT = 'InvalidParameterValue.IngressRulesConflict'
+
 # 无效的定时伸缩周期。
 INVALIDPARAMETERVALUE_INVALIDCRONSCALERPERIOD = 'InvalidParameterValue.InvalidCronScalerPeriod'
 
@@ -254,6 +275,9 @@ INVALIDPARAMETERVALUE_PORTISRESERVED = 'InvalidParameterValue.PortIsReserved'
 # post start 不合法。
 INVALIDPARAMETERVALUE_POSTSTARTNOTVALID = 'InvalidParameterValue.PostStartNotValid'
 
+# pre stop 不合法。
+INVALIDPARAMETERVALUE_PRESTOPNOTVALID = 'InvalidParameterValue.PreStopNotValid'
+
 # 公有镜像参数错误。
 INVALIDPARAMETERVALUE_PUBLICREPOTYPEPARAMETERERROR = 'InvalidParameterValue.PublicRepoTypeParameterError'
 
@@ -317,6 +341,9 @@ MISSINGPARAMETER_DEPLOYVERSIONNULL = 'MissingParameter.DeployVersionNull'
 # 环境名称不能为空。
 MISSINGPARAMETER_ENVIRONMENTNAMENULL = 'MissingParameter.EnvironmentNameNull'
 
+# 镜像仓库不能为空。
+MISSINGPARAMETER_IMGREPONULL = 'MissingParameter.ImgRepoNull'
+
 # logset 和 topic 不能为空。
 MISSINGPARAMETER_LOGSETORTOPICNULL = 'MissingParameter.LogsetOrTopicNull'
 
@@ -329,6 +356,9 @@ MISSINGPARAMETER_NAMESPACEIDNULL = 'MissingParameter.NamespaceIdNull'
 # 包名不能为空。
 MISSINGPARAMETER_PKGNAMENULL = 'MissingParameter.PkgNameNull'
 
+# 镜像仓库服务器不能为空。
+MISSINGPARAMETER_REPOSERVERNULL = 'MissingParameter.RepoServerNull'
+
 # 弹性规则ID不能为空。
 MISSINGPARAMETER_SCALERIDNULL = 'MissingParameter.ScalerIdNull'
 
@@ -362,9 +392,15 @@ RESOURCEINUSE_RESOURCEALREADYUSED = 'ResourceInUse.ResourceAlreadyUsed'
 # 服务部署中。
 RESOURCEINUSE_SERVICEDEPLOYING = 'ResourceInUse.ServiceDeploying'
 
+# 配置不存在。
+RESOURCENOTFOUND_CONFIGDATANOTFOUND = 'ResourceNotFound.ConfigDataNotFound'
+
 # 未提供该接口。
 RESOURCENOTFOUND_INTERFACENOTFOUND = 'ResourceNotFound.InterfaceNotFound'
 
+# 日志配置不存在。
+RESOURCENOTFOUND_LOGCONFIGNOTFOUND = 'ResourceNotFound.LogConfigNotFound'
+
 # 目标微服务已离线。
 RESOURCENOTFOUND_MICROSERVICEOFFLINE = 'ResourceNotFound.MicroserviceOffline'
 
