@@ -53,6 +53,9 @@ INVALIDPARAMETER_CLUSTERNOTFOUND = 'InvalidParameter.ClusterNotFound'
 # 参数错误。
 INVALIDPARAMETER_PARAM = 'InvalidParameter.Param'
 
+# 参数取值错误。
+INVALIDPARAMETERVALUE = 'InvalidParameterValue'
+
 # 操作被拒绝。
 OPERATIONDENIED = 'OperationDenied'
 
@@ -67,3 +70,6 @@ RESOURCENOTFOUND_CLUSTERNOTFOUND = 'ResourceNotFound.ClusterNotFound'
 
 # 集群状态不支持该操作。
 RESOURCEUNAVAILABLE_CLUSTERSTATE = 'ResourceUnavailable.ClusterState'
+
+# 操作不支持。
+UNSUPPORTEDOPERATION = 'UnsupportedOperation'
